==> marketplace-constants-0.1.4.1.tar.gz: marketplace-constants-0.1.4.1/mpconstants/regions/is.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afganistan',
 u'ag': u'Antig\xfaa og Barb\xfada',
 u'ai': u'Angvilla',
 u'al': u'Alban\xeda',
 u'am': u'Armen\xeda',
 u'an': u'Hollensku Antillur',
 u'ao': u'Ang\xf3la',
 u'aq': u'Antarkt\xedka',
 u'ar': u'Argent\xedna',
 u'as': u'Amer\xedsku Sam\xf3aeyjarnar',
 u'at': u'Austurr\xedki',
 u'au': u'\xc1stral\xeda',
 u'aw': u'Ar\xfaba',
 u'ax': u'\xc1landseyjar',
 u'az': u'Aserba\xeddsjan',
 u'ba': u'Bosn\xeda og Herseg\xf3v\xedna',
 u'bb': u'Barbados',
 u'bd': u'Bangladess',
 u'be': u'Belg\xeda',
 u'bf': u'B\xfark\xedna Fas\xf3',
 u'bg': u'B\xfalgar\xeda',
 u'bh': u'Barein',
 u'bi': u'B\xfar\xfand\xed',
 u'bj': u'Ben\xedn',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Berm\xfadaeyjar',
 u'bn': u'Br\xfanei',
 u'bo': u'B\xf3liv\xeda',
 u'br': u'Brasil\xeda',
 u'bs': u'Bahamaeyjar',
 u'bt': u'B\xfatan',
 u'bv': u'Bouvet-eyja',
 u'bw': u'Botsvana',
 u'by': u'Hv\xedta-R\xfassland',
 u'bz': u'Bel\xeds',
 u'ca': u'Kanada',
 u'cc': u'K\xf3koseyjar',
 u'cd': u'Austur-Kong\xf3',
 u'cf': u'Mi\xf0-Afr\xedkul\xfd\xf0veldi\xf0',
 u'cg': u'Vestur-Kong\xf3',
 u'ch': u'Sviss',
 u'ci': u'F\xedlabeinsstr\xf6ndin',
 u'ck': u'Cookseyjar',
 u'cl': u'Ch\xedle',
 u'cm': u'Kamer\xfan',
 u'cn': u'K\xedna',
 u'co': u'K\xf3lumb\xeda',
 u'cr': u'Kostar\xedka',
 u'cu': u'K\xfaba',
 u'cv': u'Gr\xe6nh\xf6f\xf0aeyjar',
 u'cx': u'Kanar\xedeyjar',
 u'cy': u'K\xfdpur',
 u'cz': u'T\xe9kkland',
 u'de': u'\xde\xfdskaland',
 u'dj': u'Dj\xedb\xfat\xed',
 u'dk': u'Danm\xf6rk',
 u'dm': u'D\xf3min\xedka',
 u'do': u'D\xf3min\xedska l\xfd\xf0veldi\xf0',
 u'dz': u'Als\xedr',
 u'ec': u'Ekvador',
 u'ee': u'Eistland',
 u'eg': u'Egyptaland',
 u'eh': u'Holland',
 u'er': u'Er\xedtrea',
 u'es': u'Sp\xe1nn',
 u'et': u'E\xfe\xed\xf3p\xeda',
 u'fi': u'Finnland',
 u'fj': u'F\xeddjieyjar',
 u'fk': u'Falklandseyjar',
 u'fm': u'M\xedkr\xf3nes\xeda',
 u'fo': u'F\xe6reyjar',
 u'fr': u'Frakkland',
 u'ga': u'Gabon',
 u'gb': u'Bretland',
 u'gd': u'Grenada',
 u'ge': u'Georg\xeda',
 u'gf': u'Franska Gv\xe6jana',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'G\xedbraltar',
 u'gl': u'Gr\xe6nland',
 u'gm': u'Gamb\xeda',
 u'gn': u'G\xednea',
 u'gp': u'Gvadel\xfapeyjar',
 u'gq': u'Mi\xf0baugs-G\xednea',
 u'gr': u'Grikkland',
 u'gs': u'Su\xf0ur-Georg\xeda og Su\xf0ur-Sandv\xedkureyjar',
 u'gt': u'Gvatemala',
 u'gu': u'Gvam',
 u'gw': u'G\xednea-Biss\xe1',
 u'gy': u'Gv\xe6jana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard og McDonalds-eyjar',
 u'hn': u'Hond\xfaras',
 u'hr': u'Kr\xf3at\xeda',
 u'ht': u'Ha\xedt\xed',
 u'hu': u'Ungverjaland',
 u'id': u'Ind\xf3nes\xeda',
 u'ie': u'\xcdrland',
 u'il': u'\xcdsrael',
 u'im': u'\xc1landseyjar',
 u'in': u'Indland',
 u'io': u'Bresku Indlandshafseyjar',
 u'iq': u'\xcdrak',
 u'ir': u'\xcdran',
 u'is': u'\xcdsland',
 u'it': u'\xcdtal\xeda',
 u'je': u'Jersey',
 u'jm': u'Jama\xedka',
 u'jo': u'J\xf3rdan\xeda',
 u'jp': u'Japan',
 u'ke': u'Ken\xeda',
 u'kg': u'Kirgistan',
 u'kh': u'Kamb\xf3d\xeda',
 u'ki': u'K\xedribat\xed',
 u'km': u'K\xf3moreyjar',
 u'kn': u'Sankti Krist\xf3fer og Nevis',
 u'kp': u'Nor\xf0ur-K\xf3rea',
 u'kr': u'Su\xf0ur-K\xf3rea\\u0020',
 u'kw': u'K\xfaveit',
 u'ky': u'Cayman eyjar',
 u'kz': u'Kasakstan',
 u'la': u'Laos',
 u'lb': u'L\xedbanon',
 u'lc': u'Sankti L\xfas\xeda',
 u'li': u'Vientiane',
 u'lk': u'Sr\xed Lanka',
 u'lr': u'L\xedber\xeda',
 u'ls': u'Les\xf3t\xf3',
 u'lt': u'Lith\xe1en',
 u'lu': u'L\xfaxemborg',
 u'lv': u'Lettland',
 u'ly': u'L\xedb\xeda',
 u'ma': u'Marokk\xf3',
 u'mc': u'M\xf3nak\xf3',
 u'md': u'Mold\xf3va',
 u'me': u'Montenegro',
 u'mf': u'Sankti Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall-eyjar',
 u'mk': u'Maked\xf3n\xeda',
 u'ml': u'Mal\xed',
 u'mm': u'Mjanmar',
 u'mn': u'Mong\xf3l\xeda',
 u'mo': u'Macao\\u0020',
 u'mp': u'Nor\xf0ur-Mar\xedanaeyjar',
 u'mq': u'Martin\xedk',
 u'mr': u'M\xe1ritan\xeda',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'M\xe1rit\xedus',
 u'mv': u'Mald\xedveyjar',
 u'mw': u'Malav\xed',
 u'mx': u'Mex\xedk\xf3',
 u'my': u'Malas\xeda',
 u'mz': u'M\xf3samb\xedk',
 u'na': u'Namib\xeda',
 u'nc': u'N\xfdja Kaled\xf3n\xeda',
 u'ne': u'N\xedger',
 u'nf': u'Norfolkeyja',
 u'ng': u'N\xedger\xeda',
 u'ni': u'N\xedkaragva',
 u'nl': u'Holland',
 u'no': u'Noregur',
 u'np': u'Nepal',
 u'nr': u'N\xe1r\xfa',
 u'nu': u'Niue',
 u'nz': u'N\xfdja-Sj\xe1land',
 u'om': u'\xd3man',
 u'pa': u'Panama',
 u'pe': u'Per\xfa',
 u'pf': u'Franska P\xf3l\xfdnes\xeda',
 u'pg': u'Pap\xfaa N\xfdja G\xednea',
 u'ph': u'Filippseyjar',
 u'pk': u'Pakistan',
 u'pl': u'P\xf3lland',
 u'pm': u'Sankti Pierre og Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'P\xfaert\xf3 R\xedk\xf3',
 u'ps': u'Palest\xedna',
 u'pt': u'Port\xfagal',
 u'pw': u'Pal\xe1',
 u'py': u'Paragv\xe6',
 u'qa': u'Katar',
 u're': u'R\xe9union',
 u'ro': u'R\xfamen\xeda',
 u'rs': u'Serb\xeda',
 u'ru': u'R\xfassland',
 u'rw': u'R\xfaanda',
 u'sa': u'Sameinu\xf0u arab\xedsku furstad\xe6min',
 u'sb': u'Sal\xf3monseyjar',
 u'sc': u'Seychelleseyjar',
 u'sd': u'S\xfadan',
 u'se': u'Sv\xed\xfej\xf3\xf0',
 u'sg': u'Singap\xfar',
 u'sh': u'Sankti Helena',
 u'si': u'Sl\xf3ven\xeda',
 u'sj': u'Svalbar\xf0i og Jan Mayen',
 u'sk': u'Sl\xf3vak\xeda',
 u'sl': u'S\xederra Le\xf3ne',
 u'sm': u'San Marin\xf3',
 u'sn': u'Senegal',
 u'so': u'S\xf3mal\xeda',
 u'sr': u'S\xfar\xednam',
 u'st': u'Sa\xf3 T\xf3me og Prins\xedpe',
 u'sv': u'El Salvador',
 u'sy': u'S\xfdrland',
 u'sz': u'Svas\xedland',
 u'tc': u'Turks og Caicoseyjar',
 u'td': u'Tsjad',
 u'tf': u'Fr\xf6nsku su\xf0l\xe6gu landsv\xe6\xf0in',
 u'tg': u'T\xf3g\xf3',
 u'th': u'T\xe6land',
 u'tj': u'Tadsjikistan',
 u'tk': u'T\xf3kel\xe1',
 u'tl': u'Austur-T\xedmor',
 u'tm': u'T\xfarkmenistan',
 u'tn': u'T\xfanis',
 u'to': u'Tonga',
 u'tr': u'Tyrkland',
 u'tt': u'Tr\xednidad',
 u'tv': u'T\xfaval\xfa',
 u'tw': u'Ta\xedvan',
 u'tz': u'Tansan\xeda',
 u'ua': u'\xdakra\xedna',
 u'ug': u'\xdaganda',
 u'um': u'Sm\xe1eyjar Bandar\xedkjanna',
 u'us': u'Bandar\xedkin',
 u'uy': u'\xdar\xfagv\xe6',
 u'uz': u'\xdasbekistan',
 u'va': u'Vat\xedkani\xf0',
 u'vc': u'Sankti Vinsent og Grenad\xedneyjar',
 u've': u'Venes\xfaela',
 u'vg': u'Bresku J\xf3mfr\xfareyjar',
 u'vi': u'J\xf3mfr\xfaaeyjar\\u0020',
 u'vn': u'V\xedetnam',
 u'vu': u'Van\xfaat\xfa',
 u'wf': u'Wallis og F\xfat\xfanaeyjar',
 u'ws': u'Sam\xf3a',
 u'ye': u'Jemen',
 u'yt': u'Maine',
 u'za': u'Su\xf0ur-Afr\xedka',
 u'zm': u'Samb\xeda',
 u'zw': u'Simbabve'}

==> marketplace-constants-0.4.0.tar.gz: marketplace-constants-0.4.0/mpconstants/regions/is.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afganistan',
 u'ag': u'Antig\xfaa og Barb\xfada',
 u'ai': u'Angvilla',
 u'al': u'Alban\xeda',
 u'am': u'Armen\xeda',
 u'an': u'Hollensku Antillur',
 u'ao': u'Ang\xf3la',
 u'aq': u'Antarkt\xedka',
 u'ar': u'Argent\xedna',
 u'as': u'Amer\xedsku Sam\xf3aeyjarnar',
 u'at': u'Austurr\xedki',
 u'au': u'\xc1stral\xeda',
 u'aw': u'Ar\xfaba',
 u'ax': u'\xc1landseyjar',
 u'az': u'Aserba\xeddsjan',
 u'ba': u'Bosn\xeda og Herseg\xf3v\xedna',
 u'bb': u'Barbados',
 u'bd': u'Bangladess',
 u'be': u'Belg\xeda',
 u'bf': u'B\xfark\xedna Fas\xf3',
 u'bg': u'B\xfalgar\xeda',
 u'bh': u'Barein',
 u'bi': u'B\xfar\xfand\xed',
 u'bj': u'Ben\xedn',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Berm\xfadaeyjar',
 u'bn': u'Br\xfanei',
 u'bo': u'B\xf3liv\xeda',
 u'br': u'Brasil\xeda',
 u'bs': u'Bahamaeyjar',
 u'bt': u'B\xfatan',
 u'bv': u'Bouvet-eyja',
 u'bw': u'Botsvana',
 u'by': u'Hv\xedta-R\xfassland',
 u'bz': u'Bel\xeds',
 u'ca': u'Kanada',
 u'cc': u'K\xf3koseyjar',
 u'cd': u'Austur-Kong\xf3',
 u'cf': u'Mi\xf0-Afr\xedkul\xfd\xf0veldi\xf0',
 u'cg': u'Vestur-Kong\xf3',
 u'ch': u'Sviss',
 u'ci': u'F\xedlabeinsstr\xf6ndin',
 u'ck': u'Cookseyjar',
 u'cl': u'Ch\xedle',
 u'cm': u'Kamer\xfan',
 u'cn': u'K\xedna',
 u'co': u'K\xf3lumb\xeda',
 u'cr': u'Kostar\xedka',
 u'cu': u'K\xfaba',
 u'cv': u'Gr\xe6nh\xf6f\xf0aeyjar',
 u'cx': u'Kanar\xedeyjar',
 u'cy': u'K\xfdpur',
 u'cz': u'T\xe9kkland',
 u'de': u'\xde\xfdskaland',
 u'dj': u'Dj\xedb\xfat\xed',
 u'dk': u'Danm\xf6rk',
 u'dm': u'D\xf3min\xedka',
 u'do': u'D\xf3min\xedska l\xfd\xf0veldi\xf0',
 u'dz': u'Als\xedr',
 u'ec': u'Ekvador',
 u'ee': u'Eistland',
 u'eg': u'Egyptaland',
 u'eh': u'Holland',
 u'er': u'Er\xedtrea',
 u'es': u'Sp\xe1nn',
 u'et': u'E\xfe\xed\xf3p\xeda',
 u'fi': u'Finnland',
 u'fj': u'F\xeddjieyjar',
 u'fk': u'Falklandseyjar',
 u'fm': u'M\xedkr\xf3nes\xeda',
 u'fo': u'F\xe6reyjar',
 u'fr': u'Frakkland',
 u'ga': u'Gabon',
 u'gb': u'Bretland',
 u'gd': u'Grenada',
 u'ge': u'Georg\xeda',
 u'gf': u'Franska Gv\xe6jana',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'G\xedbraltar',
 u'gl': u'Gr\xe6nland',
 u'gm': u'Gamb\xeda',
 u'gn': u'G\xednea',
 u'gp': u'Gvadel\xfapeyjar',
 u'gq': u'Mi\xf0baugs-G\xednea',
 u'gr': u'Grikkland',
 u'gs': u'Su\xf0ur-Georg\xeda og Su\xf0ur-Sandv\xedkureyjar',
 u'gt': u'Gvatemala',
 u'gu': u'Gvam',
 u'gw': u'G\xednea-Biss\xe1',
 u'gy': u'Gv\xe6jana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard og McDonalds-eyjar',
 u'hn': u'Hond\xfaras',
 u'hr': u'Kr\xf3at\xeda',
 u'ht': u'Ha\xedt\xed',
 u'hu': u'Ungverjaland',
 u'id': u'Ind\xf3nes\xeda',
 u'ie': u'\xcdrland',
 u'il': u'\xcdsrael',
 u'im': u'\xc1landseyjar',
 u'in': u'Indland',
 u'io': u'Bresku Indlandshafseyjar',
 u'iq': u'\xcdrak',
 u'ir': u'\xcdran',
 u'is': u'\xcdsland',
 u'it': u'\xcdtal\xeda',
 u'je': u'Jersey',
 u'jm': u'Jama\xedka',
 u'jo': u'J\xf3rdan\xeda',
 u'jp': u'Japan',
 u'ke': u'Ken\xeda',
 u'kg': u'Kirgistan',
 u'kh': u'Kamb\xf3d\xeda',
 u'ki': u'K\xedribat\xed',
 u'km': u'K\xf3moreyjar',
 u'kn': u'Sankti Krist\xf3fer og Nevis',
 u'kp': u'Nor\xf0ur-K\xf3rea',
 u'kr': u'Su\xf0ur-K\xf3rea ',
 u'kw': u'K\xfaveit',
 u'ky': u'Cayman eyjar',
 u'kz': u'Kasakstan',
 u'la': u'Laos',
 u'lb': u'L\xedbanon',
 u'lc': u'Sankti L\xfas\xeda',
 u'li': u'Vientiane',
 u'lk': u'Sr\xed Lanka',
 u'lr': u'L\xedber\xeda',
 u'ls': u'Les\xf3t\xf3',
 u'lt': u'Lith\xe1en',
 u'lu': u'L\xfaxemborg',
 u'lv': u'Lettland',
 u'ly': u'L\xedb\xeda',
 u'ma': u'Marokk\xf3',
 u'mc': u'M\xf3nak\xf3',
 u'md': u'Mold\xf3va',
 u'me': u'Montenegro',
 u'mf': u'Sankti Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall-eyjar',
 u'mk': u'Maked\xf3n\xeda',
 u'ml': u'Mal\xed',
 u'mm': u'Mjanmar',
 u'mn': u'Mong\xf3l\xeda',
 u'mo': u'Macao ',
 u'mp': u'Nor\xf0ur-Mar\xedanaeyjar',
 u'mq': u'Martin\xedk',
 u'mr': u'M\xe1ritan\xeda',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'M\xe1rit\xedus',
 u'mv': u'Mald\xedveyjar',
 u'mw': u'Malav\xed',
 u'mx': u'Mex\xedk\xf3',
 u'my': u'Malas\xeda',
 u'mz': u'M\xf3samb\xedk',
 u'na': u'Namib\xeda',
 u'nc': u'N\xfdja Kaled\xf3n\xeda',
 u'ne': u'N\xedger',
 u'nf': u'Norfolkeyja',
 u'ng': u'N\xedger\xeda',
 u'ni': u'N\xedkaragva',
 u'nl': u'Holland',
 u'no': u'Noregur',
 u'np': u'Nepal',
 u'nr': u'N\xe1r\xfa',
 u'nu': u'Niue',
 u'nz': u'N\xfdja-Sj\xe1land',
 u'om': u'\xd3man',
 u'pa': u'Panama',
 u'pe': u'Per\xfa',
 u'pf': u'Franska P\xf3l\xfdnes\xeda',
 u'pg': u'Pap\xfaa N\xfdja G\xednea',
 u'ph': u'Filippseyjar',
 u'pk': u'Pakistan',
 u'pl': u'P\xf3lland',
 u'pm': u'Sankti Pierre og Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'P\xfaert\xf3 R\xedk\xf3',
 u'ps': u'Palest\xedna',
 u'pt': u'Port\xfagal',
 u'pw': u'Pal\xe1',
 u'py': u'Paragv\xe6',
 u'qa': u'Katar',
 u're': u'R\xe9union',
 u'ro': u'R\xfamen\xeda',
 u'rs': u'Serb\xeda',
 u'ru': u'R\xfassland',
 u'rw': u'R\xfaanda',
 u'sa': u'Sameinu\xf0u arab\xedsku furstad\xe6min',
 u'sb': u'Sal\xf3monseyjar',
 u'sc': u'Seychelleseyjar',
 u'sd': u'S\xfadan',
 u'se': u'Sv\xed\xfej\xf3\xf0',
 u'sg': u'Singap\xfar',
 u'sh': u'Sankti Helena',
 u'si': u'Sl\xf3ven\xeda',
 u'sj': u'Svalbar\xf0i og Jan Mayen',
 u'sk': u'Sl\xf3vak\xeda',
 u'sl': u'S\xederra Le\xf3ne',
 u'sm': u'San Marin\xf3',
 u'sn': u'Senegal',
 u'so': u'S\xf3mal\xeda',
 u'sr': u'S\xfar\xednam',
 u'st': u'Sa\xf3 T\xf3me og Prins\xedpe',
 u'sv': u'El Salvador',
 u'sy': u'S\xfdrland',
 u'sz': u'Svas\xedland',
 u'tc': u'Turks og Caicoseyjar',
 u'td': u'Tsjad',
 u'tf': u'Fr\xf6nsku su\xf0l\xe6gu landsv\xe6\xf0in',
 u'tg': u'T\xf3g\xf3',
 u'th': u'T\xe6land',
 u'tj': u'Tadsjikistan',
 u'tk': u'T\xf3kel\xe1',
 u'tl': u'Austur-T\xedmor',
 u'tm': u'T\xfarkmenistan',
 u'tn': u'T\xfanis',
 u'to': u'Tonga',
 u'tr': u'Tyrkland',
 u'tt': u'Tr\xednidad',
 u'tv': u'T\xfaval\xfa',
 u'tw': u'Ta\xedvan',
 u'tz': u'Tansan\xeda',
 u'ua': u'\xdakra\xedna',
 u'ug': u'\xdaganda',
 u'um': u'Sm\xe1eyjar Bandar\xedkjanna',
 u'us': u'Bandar\xedkin',
 u'uy': u'\xdar\xfagv\xe6',
 u'uz': u'\xdasbekistan',
 u'va': u'Vat\xedkani\xf0',
 u'vc': u'Sankti Vinsent og Grenad\xedneyjar',
 u've': u'Venes\xfaela',
 u'vg': u'Bresku J\xf3mfr\xfareyjar',
 u'vi': u'J\xf3mfr\xfaaeyjar ',
 u'vn': u'V\xedetnam',
 u'vu': u'Van\xfaat\xfa',
 u'wf': u'Wallis og F\xfat\xfanaeyjar',
 u'ws': u'Sam\xf3a',
 u'ye': u'Jemen',
 u'yt': u'Maine',
 u'za': u'Su\xf0ur-Afr\xedka',
 u'zm': u'Samb\xeda',
 u'zw': u'Simbabve'}
